/**
 * @file
 * JavaScript behaviors for PDF Services field configuration form.
 */

(function ($, Drupal, drupalSettings) {
  'use strict';

  /**
   * Behaviors for PDF services field config form.
   */
  Drupal.behaviors.pdfServicesFieldForm = {
    attach: function (context, settings) {
      // Only run once
      once('pdf-services-field-logic', '.form-item--pdf-services-optimization-compression-level select', context).forEach(function (elem) {
        const $compressionElement = $(elem);

        // Function to handle compression level change
        function handleCompressionChange() {
          const compressionValue = $compressionElement.val();
          const propertiesCheckbox = $('#' + drupalSettings.pdfServices.fieldId);

          // If user selects any compression other than NONE, ensure properties are checked
          if (compressionValue && compressionValue !== 'NONE') {
            propertiesCheckbox.prop('checked', true);
            // Make disabled
            propertiesCheckbox.prop('disabled', true);
          } else {
            // If user selects NONE, uncheck properties and remove disabled
            propertiesCheckbox.prop('disabled', false);
          }
        }

        // Add change handler to compression level dropdown
        $compressionElement.on('change', handleCompressionChange);

        // Run on initial load
        handleCompressionChange();
      });

    }
  };
})(jQuery, Drupal, drupalSettings);
